@@ -9,7 +9,7 @@ class ConditionWrapper:
     查询SQL语句条件包装类，用于组装查询SQL语句
     """
 
-    def __init__(self, table, column=None):
+    def __init__(self, table, column="*"):
         self.table = table
         self.column = column
         self.conditions: list = []
