@@ -37,11 +37,12 @@ class DSHelper(BaseSqlHelper):
             clazz = getattr(
                 __import__("lesscode.db.elasticsearch.elasticsearch_helper", fromlist="ElasticsearchHelper"),
                 "ElasticsearchHelper")
-            # self.db_helper = ElasticsearchHelper(self.pool)
-        # elif self.dialect == "redis":
-        #     clazz = getattr(
-        #         __import__("lesscode.db.redis.redis_helper", fromlist="RedisHelper"),
-        #         "RedisHelper")
+        elif self.dialect == "esapi":
+            clazz = getattr(__import__("lesscode.db.es.es_helper", fromlist="EsHelper"), "EsHelper")
+        elif self.dialect == "redis":
+            clazz = getattr(
+                __import__("lesscode.db.redis.redis_helper", fromlist="RedisHelper"),
+                "RedisHelper")
         if clazz:
             self.db_helper = clazz(self.pool)
 
