@@ -7,7 +7,7 @@
 import inspect
 import json
 from datetime import datetime
-from typing import Optional, Awaitable
+from typing import Optional, Awaitable, Any
 
 from bson import ObjectId
 from tornado import httputil
@@ -234,6 +234,21 @@ class BaseHandler(RequestHandler):
             self.request.method, self.request.path, self.request.arguments, self.request.remote_ip,
             self.request.headers["User-Agent"])
 
+    def get_current_user(self) -> Any:
+        """
+        获取当前用户信息
+        :return:
+        """
+        user_info_json = self.request.headers.get("userInfo")
+        if user_info_json:
+            # TODO 未做加密
+            user_info = json.loads(user_info_json)
+            user = User()
+            for key in user_info:
+                setattr(user, key, user_info[key])
+            return user
+        return None
+
 
 class JSONEncoder(json.JSONEncoder):
     def default(self, o):
@@ -248,6 +263,30 @@ class JSONEncoder(json.JSONEncoder):
         return json.JSONEncoder.default(self, o)
 
 
+class User:
+    """
+    用户对象类
+    """
+    def __init__(self):
+        # '账号id',
+        self.id =None
+        # 用户名
+        self.username = None
+        # '密码',
+        self.password = None
+        # '显示名',
+        self.display_name = None
+        # 手机号,
+        self.phone_no = None
+        #  邮箱
+        self.email = None
+        # 组织机构id',
+        self.org_id = None
+        # '1正常（激活）；2未激活（管理员新增，首次登录需要改密码）； 3锁定（登录错误次数超限，锁定时长可配置）； 4休眠（长期未登录（字段，时长可配置），定时） 5禁用-账号失效；
+        self.account_status = None
+
+
+
 # 解析param
 def parse_val(val, val_type):
     # inspect.Parameter.empty <class 'NoneType'>
