@@ -57,8 +57,7 @@ def Handler(url: str):
             full_url = url + item[2]
             # 判断是否存在重复注册情况，重复情况直接抛出异常
             if [router for router in RouterMapping.instance() if full_url in router]:
-                raise BusinessException(StatusCode.MESSAGE_FORMAT(StatusCode.RESOURCE_EXIST,
-                                                                  f'路由"{full_url}"'))
+                raise BusinessException(StatusCode.RESOURCE_EXIST(f'路由"{full_url}"'))
             # 存储URL与 RequestHandler 子类对应关系，用于提供给Tornado注册使用
             RouterMapping.instance().append((full_url, cls))
             # 存储URL与处理方法的对应关系，用于调用分发使用
